
# Akhdefo


[<img src="./akhdefo_functions/_static/akhdefo_logo.svg" alt="Akhdefo Project Image" align="right" width="200px"/>](https://akhdefo.readthedocs.io/en/latest/index.html)
<em align="right">Click on the Logo to Navigate to the Main Page</em>



## Computer Vision for Slope Stability: Land Deformation Monitoring

## Background of Akh-Defo

**Akh-Defo** is derived from two distinct words: 
1. 'Akh' in the Kurdish language, representing land, earth, or soil (originating from the Kurdish Badini dialect).
2. 'Defo', a shorthand for the English term 'deformation'.

## Recommended Citation

Muhammad M, Williams-Jones G, Stead D, Tortini R, Falorni G, and Donati D (2022) Applications of Image-Based Computer Vision for Remote Surveillance of Slope Instability. *Front. Earth Sci.* 10:909078. doi: [10.3389/feart.2022.909078](https://doi.org/10.3389/feart.2022.909078)

## Updates

- **Deprecated:** Akhdefo version one. *Current recommendation:* Use Akhdefo version 2.
- **New Feature:** Cloud-based real-time processing capabilities.
- **Expansion:** Over 20 modules for end-to-end Python-based GIS and Image Processing, and Customized Figure generation.
- **Integration:** Access, filter, and download capabilities for Planet Labs data using the Planet Lab API.
- **Enhancement:** Orthorectification feature for satellite images.

## Installation of Akhdefo Software

Follow these steps to install the Akhdefo software:

1. Create a new Python Anaconda environment using the command:

   ```python
   conda create --name akhdefo_env
   ```

2. Create  Anaconda environment and install the following libraries with Anaconda

```yaml

dependencies:
  - python=3.8  # Assuming Python 3.8, can be changed as needed
  - cmocean
  - pip
  - opencv
  - earthpy
  - flask
  - geopandas
  - glob2
  - gstools
  - hyp3_sdk
  - ipywidgets
  - json5
  - matplotlib
  - numpy
  - gdal
  - pandas
  - recommonmark
  - sphinx
  - nbsphinx
  - sphinx-book-theme
  - myst-parser
  - plotly
  - pykrige
  - rasterio
  - requests
  - rioxarray
  - scipy
  - seaborn
  - shapely
  - scikit-image  # skimage
  - scikit-learn  # sklearn
  - statsmodels
  - tensorflow
  - tqdm
  - xmltodict

```
3. Download the Python package requirement file: [pip_req.txt](pip_req.txt).

4. Install required Python packages with the command:

   ```python
   pip install -r pip_req.txt
   ```

5. Install Akhdefo using the following command:

   ```python
   pip install akhdefo-functions
   ```
